## ACTIONet R Package
See [ACTIONet-R](https://github.com/shmohammadi86/ACTIONet/tree/R-release) for more information about installing/using ACTIONet R package

## ACTIONet Legacy R Package
See [ACTIONet-Legacy](https://github.com/shmohammadi86/ACTIONet/tree/legacy) for more information about installing/using ACTIONet R package (legacy)

## ACTIONet Python Package
See [ACTIONet-Python](https://github.com/shmohammadi86/ACTIONet/tree/python-devel) for more information about installing/using ACTIONet Python package
